from .Loggers import Loggers

loggers = Loggers()

loggers.set_level(loggers.INFO)

__all__ = ("loggers")
